/* Copyright © 2012 Matthew Champion
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of mattunderscore.com nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MATTHEW CHAMPION BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

package com.mattunderscore.filter.contentnegotiation.parser;

/**
 * The description of a redirect header returned by the content negotiation filter.
 * <P>
 * Used to configure responses.
 * 
 * @author Matt Champion
 * @since 0.0.13
 */
public class Redirect
{

    private static final int HASH_SEED = 13;
    private static final int HASH_MULT = 19;

    protected int code;
    protected String location;

    public Redirect()
    {
    }

    /**
     * Get the code of the redirect.
     * @return The code of the redirect
     * @since 0.0.13
     */
    public int getCode()
    {
        return code;
    }

    /**
     * Set the code of the redirect.
     * @param value The code of the redirect
     * @since 0.0.13
     */
    public void setCode(int value)
    {
        this.code = value;
    }

    /**
     * Get the location of the redirect.
     * @return The location of the redirect
     * @since 0.0.13
     */
    public String getLocation()
    {
        return location;
    }

    /**
     * Set the location of the redirect.
     * @param value The location of the redirect
     * @since 0.0.13
     */
    public void setLocation(String value)
    {
        this.location = value;
    }

    @Override
    public int hashCode()
    {
        int hash = HASH_SEED;
        hash = (hash * HASH_MULT) + code;
        if (location != null)
        {
            hash = (hash * HASH_MULT) + location.hashCode();
        }
        else
        {
            hash = (hash * HASH_MULT) + 5;
        }
        return hash;
    }

    @Override
    public boolean equals(Object o)
    {
        if (o == null)
        {
            return false;
        }
        else if (o instanceof Redirect)
        {
            Redirect co = (Redirect)o;
            if (this.location != null)
            {
                return this.code == co.code && this.location.equals(co.location);
            }
            else
            {
                return this.code == co.code && co.location == null;
            }
        }
        else
        {
            return false;
        }
    }
}
