/* Copyright © 2013 Matthew Champion
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:
    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.
    * Neither the name of mattunderscore.com nor the
      names of its contributors may be used to endorse or promote products
      derived from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL MATTHEW CHAMPION BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. */

package com.mattunderscore.filter.contentnegotiation.variantsource;

/**
 * An exception used to indicate that there is no schema needed or available. This can be returned
 * intentionally or if the {@link javax.xml.validation.Schema} object cannot be created. This implies
 * that the XML does not need to be validated.
 * 
 * @author Matt Champion
 * @since 0.2.5
 */
public class NoSchemaException extends Exception
{
    private static final long serialVersionUID = -2363071005987667800L;

    /**
     * NoSchemaException constructor that can be used to indicate there is no schema needed.
     */
    public NoSchemaException()
    {
        super("No XML Schema is available");
    }

    /**
     * NoSchemaException constructor that can be used to wrap an exception that prevented the
     * {@link javax.xml.validation.Schema} object from being created.
     * 
     * @param cause
     *            Throwable that prevented the return of the {@link javax.xml.validation.Schema}
     *            object.
     */
    public NoSchemaException(Throwable cause)
    {
        super("No XML Schema is available: " + cause.getLocalizedMessage(), cause);
    }
}
